/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DLAY.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DLAY *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DLAY_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DLAY();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DLAY::Heavy_WSTD_DLAY(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_i4ewgjRB);
  numBytes += sLine_init(&sLine_iIWn4gYg);
  numBytes += sTabhead_init(&sTabhead_YLPPLrQh, &hTable_YFLj70pI);
  numBytes += sTabread_init(&sTabread_viWJSmJW, &hTable_YFLj70pI, false);
  numBytes += sTabread_init(&sTabread_fhkBm0tP, &hTable_YFLj70pI, false);
  numBytes += sLine_init(&sLine_cEN8aC5X);
  numBytes += sLine_init(&sLine_NXn0obcI);
  numBytes += sLine_init(&sLine_k9Be5Kkk);
  numBytes += sTabhead_init(&sTabhead_NjjMcj1V, &hTable_h8oO5xQO);
  numBytes += sTabread_init(&sTabread_x4C9lIi0, &hTable_h8oO5xQO, false);
  numBytes += sTabread_init(&sTabread_2cxsuFd9, &hTable_h8oO5xQO, false);
  numBytes += sLine_init(&sLine_UODVd3vY);
  numBytes += sTabwrite_init(&sTabwrite_GJ3BCc9t, &hTable_YFLj70pI);
  numBytes += sTabwrite_init(&sTabwrite_rTYCPrSc, &hTable_h8oO5xQO);
  numBytes += sRPole_init(&sRPole_0VfDVcjP);
  numBytes += sRPole_init(&sRPole_3mtsudKs);
  numBytes += sRPole_init(&sRPole_GwftILTH);
  numBytes += sDel1_init(&sDel1_NxwR1G01);
  numBytes += sLine_init(&sLine_bHGS9tiU);
  numBytes += sLine_init(&sLine_PtwHQNXn);
  numBytes += sRPole_init(&sRPole_B1pYeYns);
  numBytes += sRPole_init(&sRPole_Ye9DWZub);
  numBytes += sRPole_init(&sRPole_hUpQhc7u);
  numBytes += sDel1_init(&sDel1_GmaGg5HW);
  numBytes += sLine_init(&sLine_MBSZxC96);
  numBytes += sLine_init(&sLine_jCbMtff5);
  numBytes += sLine_init(&sLine_4GLtBiPw);
  numBytes += sLine_init(&sLine_4XJ4sOVI);
  numBytes += cVar_init_f(&cVar_HBt27McZ, 0.0f);
  numBytes += cVar_init_f(&cVar_rXGyhlvz, 0.0f);
  numBytes += cVar_init_f(&cVar_OLDicEgA, 0.0f);
  numBytes += cVar_init_f(&cVar_l3rBFJ8Q, 0.0f);
  numBytes += cSlice_init(&cSlice_XTq1Peho, 1, -1);
  numBytes += cVar_init_f(&cVar_1NwWaPIM, 0.5f);
  numBytes += cSlice_init(&cSlice_91GGRTN9, 1, -1);
  numBytes += cVar_init_f(&cVar_elbhikIk, 0.2f);
  numBytes += cSlice_init(&cSlice_Oyw0E1Gf, 1, -1);
  numBytes += cVar_init_f(&cVar_oKWvlrBw, 500.0f);
  numBytes += cSlice_init(&cSlice_X1lWpPhr, 1, -1);
  numBytes += cVar_init_f(&cVar_SWeR982J, 0.25f);
  numBytes += cDelay_init(this, &cDelay_mQNgpff1, 0.0f);
  numBytes += cDelay_init(this, &cDelay_Ib0AglKr, 0.0f);
  numBytes += hTable_init(&hTable_YFLj70pI, 256);
  numBytes += cDelay_init(this, &cDelay_09yTX94u, 0.0f);
  numBytes += cDelay_init(this, &cDelay_h0CmH2NZ, 0.0f);
  numBytes += hTable_init(&hTable_h8oO5xQO, 256);
  numBytes += cVar_init_f(&cVar_lawuRf5L, 8000.0f);
  numBytes += cBinop_init(&cBinop_CyuJLTOP, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_vMU0dMiy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_v5146CHO, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_pwgQEUYW, 8000.0f);
  numBytes += cBinop_init(&cBinop_VJKE4Wp7, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_DAd6ytih, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5HmvK1Zs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Fcml5uix, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_RM3nEnhe, 300.0f);
  numBytes += cBinop_init(&cBinop_vXrKq15D, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_OOVwrPuo, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_gLy1Z2bz, "del-1011-delayL");
  numBytes += sVarf_init(&sVarf_pU78nV89, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_77qkPsKD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DTrFANWK, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_rJLytf7W, "del-1011-delayR");
  numBytes += sVarf_init(&sVarf_r3m81SAw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_whYretQE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_viwzkO11, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_pd4SaPDM, 8000.0f);
  numBytes += cBinop_init(&cBinop_ljEY5UF8, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_KJ5sTtEX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QXDg9BZ9, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_9v5xAdIW, 8000.0f);
  numBytes += cBinop_init(&cBinop_O0cJWmIv, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_IagRjS0l, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NQAOVQKO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_y4u6YPMT, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_PpCWh6Ur, 300.0f);
  numBytes += cBinop_init(&cBinop_JPk55Hif, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_Ur5IEA21, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hf1JNuN7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IxUMAFea, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_3xGnd2Z2, 1.0f);
  numBytes += cIf_init(&cIf_SZn20hgI, false);
  numBytes += cIf_init(&cIf_LCapeWLX, false);
  numBytes += cVar_init_f(&cVar_XoxogcfD, 0.0f);
  numBytes += cVar_init_f(&cVar_yKIWypgw, 0.0f);
  numBytes += cVar_init_f(&cVar_4bl0EB9d, 60000.0f);
  numBytes += cVar_init_f(&cVar_YTlXLwEv, 500.0f);
  numBytes += cSlice_init(&cSlice_PspigQUr, 1, -1);
  numBytes += cSlice_init(&cSlice_1s9waHBf, 1, -1);
  numBytes += cVar_init_f(&cVar_YirgkVvW, 0.0f);
  numBytes += cIf_init(&cIf_7xNfttwe, false);
  numBytes += cBinop_init(&cBinop_NGQ0jzdZ, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_Rztw5a2N, 120.0f);
  numBytes += cBinop_init(&cBinop_ep0ev1y6, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_obhmo8q5, 0.0f); // __mul
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DLAY::~Heavy_WSTD_DLAY() {
  hTable_free(&hTable_YFLj70pI);
  hTable_free(&hTable_h8oO5xQO);
}

HvTable *Heavy_WSTD_DLAY::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x33B09DD4: return &hTable_YFLj70pI; // del-1011-delayL
    case 0xF057CB49: return &hTable_h8oO5xQO; // del-1011-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DLAY::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xB6A8F09D: { // Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LT5UkcVX_sendMessage);
      break;
    }
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vC0GlWQh_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dp0IbzVZ_sendMessage);
      break;
    }
    case 0x4A331B66: { // Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_z422dhO6_sendMessage);
      break;
    }
    case 0x58E5C2DB: { // Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8VIiLPwX_sendMessage);
      break;
    }
    case 0x49107604: { // TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DvpPxRo1_sendMessage);
      break;
    }
    case 0xD640D30E: { // 1011-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FKZi4nwp_sendMessage);
      break;
    }
    case 0xC82F3AD1: { // 1011-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZMJFje2f_sendMessage);
      break;
    }
    case 0x6E7C47FF: { // 1011-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UdmllURU_sendMessage);
      break;
    }
    case 0xD896CBA3: { // 1011-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uMphTUMW_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_caCMGiM5_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QRWTrIpJ_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DLAY::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Cross";
        info->hash = 0xB6A8F09D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 1: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Sync";
        info->hash = 0x4A331B66;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "Time";
        info->hash = 0x58E5C2DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 5: {
        info->name = "TimeSync";
        info->hash = 0x49107604;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 6;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DLAY::cVar_HBt27McZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vKB1oXyr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_rXGyhlvz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iePaMzlt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_OLDicEgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RyYaoGyW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_l3rBFJ8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UIlRwQeO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_0cYJtBHi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XTq1Peho, 0, m, &cSlice_XTq1Peho_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_XTq1Peho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hLb7oJ2G_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hLb7oJ2G_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_1NwWaPIM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hLb7oJ2G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_hLb7oJ2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UdmllURU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_seM9Ol8Q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_91GGRTN9, 0, m, &cSlice_91GGRTN9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_geIC6M5y_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_91GGRTN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GinrT41S_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GinrT41S_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_elbhikIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GinrT41S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_GinrT41S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FKZi4nwp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_L2rHbuCs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Oyw0E1Gf, 0, m, &cSlice_Oyw0E1Gf_sendMessage);
      break;
    }
    default: {
      cSwitchcase_0cYJtBHi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_Oyw0E1Gf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wSjbVq4c_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wSjbVq4c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_oKWvlrBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wSjbVq4c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_wSjbVq4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uMphTUMW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_1cFzpmeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_fjpdguEH_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_fjpdguEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_jVXP8Rz3_sendMessage);
}

void Heavy_WSTD_DLAY::cUnop_V1JZcU0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XTXAoiy5_sendMessage(_c, 0, m);
  cMsg_AzenB1Cx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cUnop_BynkYy3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QE8GlEYF_sendMessage(_c, 0, m);
  cMsg_s70wm75W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_jVXP8Rz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_2XlSDKLb_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_2XlSDKLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5UPOp2un_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lA428NjI_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_lA428NjI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vHp25dfT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_5UPOp2un_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8zfIU7Jf_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_8zfIU7Jf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ESGlodat_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_vHp25dfT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_enFfVOEu_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_enFfVOEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SzK9JAeL_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ESGlodat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_V1JZcU0C_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_SzK9JAeL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_BynkYy3V_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_sjeJqAyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_7ZGR37Wu_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_7ZGR37Wu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_mw8kppi6_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_mw8kppi6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_hRBdVJde_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_hRBdVJde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QyYrLKfd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NHZKzxbf_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_NHZKzxbf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WNKVm6Ds_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_QyYrLKfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_maKd0iky_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_maKd0iky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Q2B6OT6A_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_WNKVm6Ds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_oCeE4mae_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_oCeE4mae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4P6AHMZG_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_4P6AHMZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LpKscgts_sendMessage(_c, 0, m);
  cMsg_gz8gpQqe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_Q2B6OT6A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gea9t3fz_sendMessage(_c, 0, m);
  cMsg_KSpP8eAE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_geIC6M5y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_X1lWpPhr, 0, m, &cSlice_X1lWpPhr_sendMessage);
      break;
    }
    default: {
      cSwitchcase_L2rHbuCs_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_X1lWpPhr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_V5F6RHF3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_V5F6RHF3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_SWeR982J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_V5F6RHF3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_V5F6RHF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZMJFje2f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_wqpnBpVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_neiuMteZ_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_neiuMteZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ojYn823S_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_mQNgpff1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mQNgpff1, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ib0AglKr, 0, m, &cDelay_Ib0AglKr_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mQNgpff1, 0, m, &cDelay_mQNgpff1_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_GJ3BCc9t, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_Ib0AglKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ib0AglKr, m);
  cMsg_r32E73a2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_JvxeqZUX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_wek2LqE1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_x3swRFnv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xLAJtdfF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_YFLj70pI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ba2mFBhW_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mQNgpff1, 2, m, &cDelay_mQNgpff1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oMcD3qUg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_xLAJtdfF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_YFLj70pI, 0, m, &hTable_YFLj70pI_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ojYn823S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_x3swRFnv_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_r32E73a2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_YFLj70pI, 0, m, &hTable_YFLj70pI_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_oMcD3qUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mQNgpff1, 0, m, &cDelay_mQNgpff1_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Ba2mFBhW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ib0AglKr, 2, m, &cDelay_Ib0AglKr_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_wek2LqE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_GJ3BCc9t, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_9BFiY6eY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xipmJnVM_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_xipmJnVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_CVCNO3hi_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_09yTX94u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_09yTX94u, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_h0CmH2NZ, 0, m, &cDelay_h0CmH2NZ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_09yTX94u, 0, m, &cDelay_09yTX94u_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_rTYCPrSc, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_h0CmH2NZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_h0CmH2NZ, m);
  cMsg_gAUKdhzi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_Diqbtbq5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ESBVIShu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_57qVBdIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BmQW7WrV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_h8oO5xQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GzjG9xqi_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_09yTX94u, 2, m, &cDelay_09yTX94u_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7DlSsOro_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_BmQW7WrV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_h8oO5xQO, 0, m, &hTable_h8oO5xQO_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_CVCNO3hi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_57qVBdIf_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_gAUKdhzi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_h8oO5xQO, 0, m, &hTable_h8oO5xQO_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_7DlSsOro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_09yTX94u, 0, m, &cDelay_09yTX94u_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_GzjG9xqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_h0CmH2NZ, 2, m, &cDelay_h0CmH2NZ_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ESBVIShu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_rTYCPrSc, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_lawuRf5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CyuJLTOP, HV_BINOP_MULTIPLY, 0, m, &cBinop_CyuJLTOP_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_2yQ24s62_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hLtrFgOW_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_hLtrFgOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_beHbEIvT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_CyuJLTOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_ZOpRdyxd_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ZZdvTlpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CyuJLTOP, HV_BINOP_MULTIPLY, 1, m, &cBinop_CyuJLTOP_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_beHbEIvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ZZdvTlpq_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ZOpRdyxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_YDlDYMyf_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_YDlDYMyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Jgjnj5LZ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_v5146CHO, m);
}

void Heavy_WSTD_DLAY::cBinop_Jgjnj5LZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_vMU0dMiy, m);
}

void Heavy_WSTD_DLAY::cVar_pwgQEUYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VJKE4Wp7, HV_BINOP_MULTIPLY, 0, m, &cBinop_VJKE4Wp7_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_nBaBfBKk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Iujenfsi_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_Iujenfsi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_10SQV1Yt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_VJKE4Wp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_0YPgjrGh_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_pZrvXAJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VJKE4Wp7, HV_BINOP_MULTIPLY, 1, m, &cBinop_VJKE4Wp7_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_10SQV1Yt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pZrvXAJ0_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_0YPgjrGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_cIyFQyfv_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_cIyFQyfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_NW1bbwDg_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_5HmvK1Zs, m);
}

void Heavy_WSTD_DLAY::cBinop_NW1bbwDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_DAd6ytih, m);
}

void Heavy_WSTD_DLAY::cBinop_pZyTyxc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_oDK9yLzS_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_oDK9yLzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xtQxSKu5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vBtq5R3g_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_RM3nEnhe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_i5oRyyE1_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_fuqZuI1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_g6Couqg4_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_g6Couqg4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vXrKq15D, HV_BINOP_DIVIDE, 1, m, &cBinop_vXrKq15D_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_xtQxSKu5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HJQdHOFL_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_HJQdHOFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_OOVwrPuo, m);
}

void Heavy_WSTD_DLAY::cMsg_J6yiBQlE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_b4nlLuOX_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_b4nlLuOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_pZyTyxc5_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_vBtq5R3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Fcml5uix, m);
}

void Heavy_WSTD_DLAY::cBinop_i5oRyyE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_Q8aTasbd_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Q8aTasbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vXrKq15D, HV_BINOP_DIVIDE, 0, m, &cBinop_vXrKq15D_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_vXrKq15D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J6yiBQlE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_QTgIj6tS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_6PladIuw_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_6PladIuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_7vkrnjda_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_gLy1Z2bz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_twwijg3e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_vQqezcfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_zMaAcVPe_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_pU78nV89, m);
}

void Heavy_WSTD_DLAY::cBinop_7vkrnjda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_77qkPsKD, m);
}

void Heavy_WSTD_DLAY::cMsg_twwijg3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vQqezcfW_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_zMaAcVPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_DTrFANWK, m);
}

void Heavy_WSTD_DLAY::cMsg_Wda4V83N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_W4fcm0Dx_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_W4fcm0Dx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Ekp02bmg_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_rJLytf7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NwC22CkT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_mEkZXRZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_MguaklEV_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_r3m81SAw, m);
}

void Heavy_WSTD_DLAY::cBinop_Ekp02bmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_whYretQE, m);
}

void Heavy_WSTD_DLAY::cMsg_NwC22CkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mEkZXRZ8_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_MguaklEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_viwzkO11, m);
}

void Heavy_WSTD_DLAY::cVar_pd4SaPDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ljEY5UF8, HV_BINOP_MULTIPLY, 0, m, &cBinop_ljEY5UF8_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_dGcJt85I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_saN2EeIb_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_saN2EeIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bUxABRfa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_ljEY5UF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_lTt8KwB0_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_EHlcJsUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ljEY5UF8, HV_BINOP_MULTIPLY, 1, m, &cBinop_ljEY5UF8_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_bUxABRfa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_EHlcJsUV_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_lTt8KwB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Da9fts4e_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Da9fts4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_myLrp0e6_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_QXDg9BZ9, m);
}

void Heavy_WSTD_DLAY::cBinop_myLrp0e6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_KJ5sTtEX, m);
}

void Heavy_WSTD_DLAY::cVar_9v5xAdIW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O0cJWmIv, HV_BINOP_MULTIPLY, 0, m, &cBinop_O0cJWmIv_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_wUt1WyA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_t9MwQv3V_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_t9MwQv3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E6Isvf5Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_O0cJWmIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_7IsIVz9K_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_CDukLfOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O0cJWmIv, HV_BINOP_MULTIPLY, 1, m, &cBinop_O0cJWmIv_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_E6Isvf5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_CDukLfOc_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_7IsIVz9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_0ExelSA9_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_0ExelSA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_rznJEGE6_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_NQAOVQKO, m);
}

void Heavy_WSTD_DLAY::cBinop_rznJEGE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_IagRjS0l, m);
}

void Heavy_WSTD_DLAY::cBinop_fBjLrWbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LbTbR5Sg_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_LbTbR5Sg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rMWyqP1o_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_PUAu50wT_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_PpCWh6Ur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_ToMXzviG_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Dz9a1h2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_l01tTrJ0_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_l01tTrJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JPk55Hif, HV_BINOP_DIVIDE, 1, m, &cBinop_JPk55Hif_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_rMWyqP1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jhXRhqde_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_jhXRhqde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Ur5IEA21, m);
}

void Heavy_WSTD_DLAY::cMsg_CtD3Sg8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_HWX2Wfll_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_HWX2Wfll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_fBjLrWbE_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_PUAu50wT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_y4u6YPMT, m);
}

void Heavy_WSTD_DLAY::cBinop_ToMXzviG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_HMofqdqr_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_HMofqdqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JPk55Hif, HV_BINOP_DIVIDE, 0, m, &cBinop_JPk55Hif_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_JPk55Hif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CtD3Sg8v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_XTXAoiy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cEN8aC5X, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_QE8GlEYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_i4ewgjRB, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_s70wm75W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NXn0obcI, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_AzenB1Cx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UODVd3vY, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_KSpP8eAE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jCbMtff5, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_LpKscgts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PtwHQNXn, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_Gea9t3fz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4XJ4sOVI, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_gz8gpQqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4GLtBiPw, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_hCa9f0F1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iIWn4gYg, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_Oqk72Z79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_k9Be5Kkk, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_Sszk6Mpr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bHGS9tiU, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_VXx73bMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MBSZxC96, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_3xGnd2Z2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6dDgHLNz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8LESIktw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_NLFAna0a_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_6dDgHLNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3xGnd2Z2, 1, m, &cVar_3xGnd2Z2_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_SZn20hgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_rXGyhlvz, 0, m, &cVar_rXGyhlvz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cIf_LCapeWLX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_rXGyhlvz, 0, m, &cVar_rXGyhlvz_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_XoxogcfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LCapeWLX, 0, m, &cIf_LCapeWLX_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_yKIWypgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SZn20hgI, 0, m, &cIf_SZn20hgI_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_4bl0EB9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ep0ev1y6, HV_BINOP_DIVIDE, 0, m, &cBinop_ep0ev1y6_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_YTlXLwEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_obhmo8q5, HV_BINOP_MULTIPLY, 1, m, &cBinop_obhmo8q5_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_1Y6cDdvE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PspigQUr, 0, m, &cSlice_PspigQUr_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1s9waHBf, 0, m, &cSlice_1s9waHBf_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PjAHIBZv_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TeYdF6Qk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_PspigQUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_YirgkVvW, 0, m, &cVar_YirgkVvW_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_YirgkVvW, 0, m, &cVar_YirgkVvW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cSlice_1s9waHBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_NGQ0jzdZ, HV_BINOP_NEQ, 1, m, &cBinop_NGQ0jzdZ_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_YirgkVvW, 1, m, &cVar_YirgkVvW_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_NGQ0jzdZ, HV_BINOP_NEQ, 1, m, &cBinop_NGQ0jzdZ_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_YirgkVvW, 1, m, &cVar_YirgkVvW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_YirgkVvW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_nBdhto1X_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_7xNfttwe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V6QWdXgS_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_On5Jdi1W_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cCast_On5Jdi1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YirgkVvW, 0, m, &cVar_YirgkVvW_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_V6QWdXgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NGQ0jzdZ, HV_BINOP_NEQ, 1, m, &cBinop_NGQ0jzdZ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_NGQ0jzdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7xNfttwe, 1, m, &cIf_7xNfttwe_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_TeYdF6Qk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7xNfttwe, 0, m, &cIf_7xNfttwe_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_PjAHIBZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NGQ0jzdZ, HV_BINOP_NEQ, 0, m, &cBinop_NGQ0jzdZ_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_Rztw5a2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OZOQ9ypI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vObNuNuE_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_WeaS1T29_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FtOB7Z8u_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lnpqJXnZ_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Cstpg1FJ_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_beDjFK9t_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xobY8dPH_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BgHMv6Og_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IBy1QVB6_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ecU1ooT4_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tmzus9eO_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_puwryAN4_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jn22PHpu_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uXQFlwcG_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ci7x0FAS_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cCast_FtOB7Z8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4pCSJsSO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_lnpqJXnZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QTFGIFjh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_Cstpg1FJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9jQmrcBy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_beDjFK9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3zlF6DUW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_xobY8dPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zN4mJyir_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_BgHMv6Og_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BCzG9D3Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_IBy1QVB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XPvtIOKu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_ecU1ooT4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JOIkVPOT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_tmzus9eO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hu5ec39c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_puwryAN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sxAcUF5l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_Jn22PHpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BYKBzeKJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_uXQFlwcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RdYMiN2v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_Ci7x0FAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jkYRKY4z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_ep0ev1y6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_obhmo8q5, HV_BINOP_MULTIPLY, 0, m, &cBinop_obhmo8q5_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_obhmo8q5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1Y6cDdvE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cCast_vObNuNuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4bl0EB9d, 0, m, &cVar_4bl0EB9d_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YTlXLwEv, 0, m, &cVar_YTlXLwEv_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_OZOQ9ypI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ep0ev1y6, HV_BINOP_DIVIDE, 1, m, &cBinop_ep0ev1y6_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_QpEL6sZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YTlXLwEv, 0, m, &cVar_YTlXLwEv_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_CDHf4t6x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4bl0EB9d, 0, m, &cVar_4bl0EB9d_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_4pCSJsSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QpEL6sZo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CDHf4t6x_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_QTFGIFjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QpEL6sZo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CDHf4t6x_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_9jQmrcBy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QpEL6sZo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CDHf4t6x_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_3zlF6DUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QpEL6sZo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CDHf4t6x_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_zN4mJyir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QpEL6sZo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CDHf4t6x_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_BCzG9D3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QpEL6sZo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CDHf4t6x_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_XPvtIOKu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QpEL6sZo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CDHf4t6x_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_JOIkVPOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QpEL6sZo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CDHf4t6x_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_hu5ec39c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QpEL6sZo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CDHf4t6x_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_sxAcUF5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QpEL6sZo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CDHf4t6x_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_BYKBzeKJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QpEL6sZo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CDHf4t6x_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_RdYMiN2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QpEL6sZo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CDHf4t6x_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_jkYRKY4z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QpEL6sZo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CDHf4t6x_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_UIlRwQeO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_seM9Ol8Q_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_vKB1oXyr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_seM9Ol8Q_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_4nKNO2yl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_l3rBFJ8Q, 0, m, &cVar_l3rBFJ8Q_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_qjmHIHFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HBt27McZ, 0, m, &cVar_HBt27McZ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_8a6HkQUn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OLDicEgA, 0, m, &cVar_OLDicEgA_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_iePaMzlt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_seM9Ol8Q_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_RyYaoGyW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_seM9Ol8Q_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_nBdhto1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yKIWypgw, 0, m, &cVar_yKIWypgw_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_NLFAna0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zFp2ZvGM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k7Tr0rme_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_8LESIktw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CRKFQJru_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GPQcHGsw_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_CRKFQJru_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LCapeWLX, 1, m, &cIf_LCapeWLX_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_GPQcHGsw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XoxogcfD, 0, m, &cVar_XoxogcfD_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_zFp2ZvGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SZn20hgI, 1, m, &cIf_SZn20hgI_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_k7Tr0rme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yKIWypgw, 0, m, &cVar_yKIWypgw_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_dp0IbzVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_4nKNO2yl_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_vC0GlWQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_qjmHIHFc_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_LT5UkcVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_8a6HkQUn_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_8VIiLPwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XoxogcfD, 0, m, &cVar_XoxogcfD_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_uMphTUMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hCa9f0F1_sendMessage(_c, 0, m);
  cMsg_Oqk72Z79_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_ZMJFje2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Sszk6Mpr_sendMessage(_c, 0, m);
  cMsg_VXx73bMD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_UdmllURU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_1cFzpmeB_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_QRWTrIpJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1NwWaPIM, 0, m, &cVar_1NwWaPIM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_elbhikIk, 0, m, &cVar_elbhikIk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oKWvlrBw, 0, m, &cVar_oKWvlrBw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SWeR982J, 0, m, &cVar_SWeR982J_sendMessage);
  cMsg_wqpnBpVn_sendMessage(_c, 0, m);
  cMsg_9BFiY6eY_sendMessage(_c, 0, m);
  cMsg_2yQ24s62_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_lawuRf5L, 0, m, &cVar_lawuRf5L_sendMessage);
  cMsg_nBaBfBKk_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_pwgQEUYW, 0, m, &cVar_pwgQEUYW_sendMessage);
  cMsg_fuqZuI1m_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_RM3nEnhe, 0, m, &cVar_RM3nEnhe_sendMessage);
  cMsg_dGcJt85I_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_pd4SaPDM, 0, m, &cVar_pd4SaPDM_sendMessage);
  cMsg_wUt1WyA1_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_9v5xAdIW, 0, m, &cVar_9v5xAdIW_sendMessage);
  cMsg_Dz9a1h2D_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PpCWh6Ur, 0, m, &cVar_PpCWh6Ur_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gLy1Z2bz, 0, m, &cVar_gLy1Z2bz_sendMessage);
  cMsg_QTgIj6tS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_rJLytf7W, 0, m, &cVar_rJLytf7W_sendMessage);
  cMsg_Wda4V83N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_FKZi4nwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_sjeJqAyI_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_z422dhO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3xGnd2Z2, 0, m, &cVar_3xGnd2Z2_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_caCMGiM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Rztw5a2N, 0, m, &cVar_Rztw5a2N_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_DvpPxRo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WeaS1T29_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DLAY::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_i4ewgjRB, VOf(Bf0));
    __hv_line_f(&sLine_iIWn4gYg, VOf(Bf1));
    __hv_tabhead_f(&sTabhead_YLPPLrQh, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf3), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_77qkPsKD, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_DTrFANWK, VOf(Bf1));
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf3));
    __hv_varread_f(&sVarf_pU78nV89, VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_lt_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_cast_fi(VIf(Bf4), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_viWJSmJW, VIi(Bi1), VOf(Bf4));
    __hv_tabread_if(&sTabread_fhkBm0tP, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf4), VIf(Bf1), VOf(Bf4));
    __hv_sub_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_cEN8aC5X, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_NXn0obcI, VOf(Bf0));
    __hv_line_f(&sLine_k9Be5Kkk, VOf(Bf4));
    __hv_tabhead_f(&sTabhead_NjjMcj1V, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf5), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_whYretQE, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_viwzkO11, VOf(Bf4));
    __hv_min_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf5));
    __hv_varread_f(&sVarf_r3m81SAw, VOf(Bf4));
    __hv_zero_f(VOf(Bf6));
    __hv_lt_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_and_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_cast_fi(VIf(Bf6), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_x4C9lIi0, VIi(Bi1), VOf(Bf6));
    __hv_tabread_if(&sTabread_2cxsuFd9, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf6));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf6), VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_UODVd3vY, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(I1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_hf1JNuN7, VOf(Bf0));
    __hv_add_f(VIf(I0), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_GJ3BCc9t, VIf(Bf0));
    __hv_varread_f(&sVarf_IxUMAFea, VOf(Bf0));
    __hv_add_f(VIf(I1), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_rTYCPrSc, VIf(Bf0));
    __hv_varread_f(&sVarf_v5146CHO, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_vMU0dMiy, VOf(Bf1));
    __hv_rpole_f(&sRPole_0VfDVcjP, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_5HmvK1Zs, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_DAd6ytih, VOf(Bf1));
    __hv_rpole_f(&sRPole_3mtsudKs, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Fcml5uix, VOf(Bf0));
    __hv_rpole_f(&sRPole_GwftILTH, VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_NxwR1G01, VIf(Bf0), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_OOVwrPuo, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_bHGS9tiU, VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_PtwHQNXn, VOf(Bf0));
    __hv_varread_f(&sVarf_QXDg9BZ9, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_KJ5sTtEX, VOf(Bf4));
    __hv_rpole_f(&sRPole_B1pYeYns, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_NQAOVQKO, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_IagRjS0l, VOf(Bf4));
    __hv_rpole_f(&sRPole_Ye9DWZub, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_y4u6YPMT, VOf(Bf6));
    __hv_rpole_f(&sRPole_hUpQhc7u, VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_GmaGg5HW, VIf(Bf6), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_Ur5IEA21, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_MBSZxC96, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_jCbMtff5, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_hf1JNuN7, VIf(Bf6));
    __hv_line_f(&sLine_4GLtBiPw, VOf(Bf6));
    __hv_line_f(&sLine_4XJ4sOVI, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf4), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_IxUMAFea, VIf(Bf0));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DLAY::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DLAY::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
