/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_DLAY_HPP_
#define _HEAVY_CONTEXT_WSTD_DLAY_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlCast.h"
#include "HvSignalRPole.h"
#include "HvControlVar.h"
#include "HvControlDelay.h"
#include "HvTable.h"
#include "HvControlIf.h"
#include "HvSignalLine.h"
#include "HvSignalTabwrite.h"
#include "HvControlSystem.h"
#include "HvControlUnop.h"
#include "HvSignalTabread.h"
#include "HvControlBinop.h"
#include "HvMath.h"
#include "HvSignalDel1.h"
#include "HvSignalVar.h"
#include "HvControlSlice.h"

class Heavy_WSTD_DLAY : public HeavyContext {

 public:
  Heavy_WSTD_DLAY(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_DLAY();

  const char *getName() override { return "WSTD_DLAY"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CROSS = 0xB6A8F09D, // Cross
        FEEDBACK = 0x57157946, // Feedback
        MIX = 0x97D46AC6, // Mix
        SYNC = 0x4A331B66, // Sync
        TIME = 0x58E5C2DB, // Time
        TIMESYNC = 0x49107604, // TimeSync
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_HBt27McZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rXGyhlvz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OLDicEgA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_l3rBFJ8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0cYJtBHi_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_XTq1Peho_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1NwWaPIM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hLb7oJ2G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_seM9Ol8Q_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_91GGRTN9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_elbhikIk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_GinrT41S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_L2rHbuCs_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Oyw0E1Gf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oKWvlrBw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_wSjbVq4c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1cFzpmeB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fjpdguEH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_V1JZcU0C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_BynkYy3V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jVXP8Rz3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2XlSDKLb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lA428NjI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5UPOp2un_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8zfIU7Jf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vHp25dfT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_enFfVOEu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ESGlodat_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SzK9JAeL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sjeJqAyI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7ZGR37Wu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mw8kppi6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hRBdVJde_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NHZKzxbf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QyYrLKfd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_maKd0iky_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WNKVm6Ds_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oCeE4mae_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4P6AHMZG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q2B6OT6A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_geIC6M5y_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_X1lWpPhr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SWeR982J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_V5F6RHF3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wqpnBpVn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_neiuMteZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_mQNgpff1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Ib0AglKr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_JvxeqZUX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_x3swRFnv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_YFLj70pI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xLAJtdfF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ojYn823S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r32E73a2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oMcD3qUg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ba2mFBhW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wek2LqE1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9BFiY6eY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xipmJnVM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_09yTX94u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_h0CmH2NZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Diqbtbq5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_57qVBdIf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_h8oO5xQO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BmQW7WrV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CVCNO3hi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gAUKdhzi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7DlSsOro_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GzjG9xqi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ESBVIShu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lawuRf5L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2yQ24s62_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hLtrFgOW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CyuJLTOP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZZdvTlpq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_beHbEIvT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZOpRdyxd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YDlDYMyf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jgjnj5LZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pwgQEUYW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nBaBfBKk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Iujenfsi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VJKE4Wp7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pZrvXAJ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_10SQV1Yt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0YPgjrGh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cIyFQyfv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NW1bbwDg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pZyTyxc5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oDK9yLzS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RM3nEnhe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fuqZuI1m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_g6Couqg4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xtQxSKu5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HJQdHOFL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_J6yiBQlE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b4nlLuOX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vBtq5R3g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i5oRyyE1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q8aTasbd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vXrKq15D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QTgIj6tS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_6PladIuw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gLy1Z2bz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_vQqezcfW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7vkrnjda_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_twwijg3e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zMaAcVPe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Wda4V83N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_W4fcm0Dx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rJLytf7W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_mEkZXRZ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ekp02bmg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NwC22CkT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MguaklEV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pd4SaPDM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dGcJt85I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_saN2EeIb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ljEY5UF8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EHlcJsUV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bUxABRfa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lTt8KwB0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Da9fts4e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_myLrp0e6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9v5xAdIW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wUt1WyA1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_t9MwQv3V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O0cJWmIv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CDukLfOc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E6Isvf5Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7IsIVz9K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0ExelSA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rznJEGE6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fBjLrWbE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LbTbR5Sg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PpCWh6Ur_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Dz9a1h2D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_l01tTrJ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rMWyqP1o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jhXRhqde_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CtD3Sg8v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HWX2Wfll_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PUAu50wT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ToMXzviG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HMofqdqr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JPk55Hif_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XTXAoiy5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QE8GlEYF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s70wm75W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AzenB1Cx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KSpP8eAE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LpKscgts_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Gea9t3fz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gz8gpQqe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hCa9f0F1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Oqk72Z79_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Sszk6Mpr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VXx73bMD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3xGnd2Z2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6dDgHLNz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SZn20hgI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_LCapeWLX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XoxogcfD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yKIWypgw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4bl0EB9d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YTlXLwEv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1Y6cDdvE_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_PspigQUr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_1s9waHBf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YirgkVvW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_7xNfttwe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_On5Jdi1W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V6QWdXgS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NGQ0jzdZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TeYdF6Qk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PjAHIBZv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Rztw5a2N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WeaS1T29_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_FtOB7Z8u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lnpqJXnZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Cstpg1FJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_beDjFK9t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xobY8dPH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BgHMv6Og_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IBy1QVB6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ecU1ooT4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tmzus9eO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_puwryAN4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Jn22PHpu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uXQFlwcG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ci7x0FAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ep0ev1y6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_obhmo8q5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vObNuNuE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OZOQ9ypI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QpEL6sZo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CDHf4t6x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4pCSJsSO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QTFGIFjh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9jQmrcBy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3zlF6DUW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zN4mJyir_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BCzG9D3Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XPvtIOKu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JOIkVPOT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hu5ec39c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sxAcUF5l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BYKBzeKJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RdYMiN2v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jkYRKY4z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UIlRwQeO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vKB1oXyr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4nKNO2yl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qjmHIHFc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8a6HkQUn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iePaMzlt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RyYaoGyW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nBdhto1X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NLFAna0a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8LESIktw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CRKFQJru_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GPQcHGsw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zFp2ZvGM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_k7Tr0rme_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dp0IbzVZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vC0GlWQh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LT5UkcVX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8VIiLPwX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uMphTUMW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZMJFje2f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UdmllURU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QRWTrIpJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FKZi4nwp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_z422dhO6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_caCMGiM5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DvpPxRo1_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_i4ewgjRB;
  SignalLine sLine_iIWn4gYg;
  SignalTabhead sTabhead_YLPPLrQh;
  SignalTabread sTabread_viWJSmJW;
  SignalTabread sTabread_fhkBm0tP;
  SignalLine sLine_cEN8aC5X;
  SignalLine sLine_NXn0obcI;
  SignalLine sLine_k9Be5Kkk;
  SignalTabhead sTabhead_NjjMcj1V;
  SignalTabread sTabread_x4C9lIi0;
  SignalTabread sTabread_2cxsuFd9;
  SignalLine sLine_UODVd3vY;
  SignalTabwrite sTabwrite_GJ3BCc9t;
  SignalTabwrite sTabwrite_rTYCPrSc;
  SignalRPole sRPole_0VfDVcjP;
  SignalRPole sRPole_3mtsudKs;
  SignalRPole sRPole_GwftILTH;
  SignalDel1 sDel1_NxwR1G01;
  SignalLine sLine_bHGS9tiU;
  SignalLine sLine_PtwHQNXn;
  SignalRPole sRPole_B1pYeYns;
  SignalRPole sRPole_Ye9DWZub;
  SignalRPole sRPole_hUpQhc7u;
  SignalDel1 sDel1_GmaGg5HW;
  SignalLine sLine_MBSZxC96;
  SignalLine sLine_jCbMtff5;
  SignalLine sLine_4GLtBiPw;
  SignalLine sLine_4XJ4sOVI;
  ControlVar cVar_HBt27McZ;
  ControlVar cVar_rXGyhlvz;
  ControlVar cVar_OLDicEgA;
  ControlVar cVar_l3rBFJ8Q;
  ControlSlice cSlice_XTq1Peho;
  ControlVar cVar_1NwWaPIM;
  ControlSlice cSlice_91GGRTN9;
  ControlVar cVar_elbhikIk;
  ControlSlice cSlice_Oyw0E1Gf;
  ControlVar cVar_oKWvlrBw;
  ControlBinop cBinop_1cFzpmeB;
  ControlBinop cBinop_fjpdguEH;
  ControlBinop cBinop_jVXP8Rz3;
  ControlBinop cBinop_2XlSDKLb;
  ControlBinop cBinop_8zfIU7Jf;
  ControlBinop cBinop_enFfVOEu;
  ControlBinop cBinop_ESGlodat;
  ControlBinop cBinop_SzK9JAeL;
  ControlBinop cBinop_sjeJqAyI;
  ControlBinop cBinop_7ZGR37Wu;
  ControlBinop cBinop_mw8kppi6;
  ControlBinop cBinop_hRBdVJde;
  ControlBinop cBinop_maKd0iky;
  ControlBinop cBinop_oCeE4mae;
  ControlBinop cBinop_4P6AHMZG;
  ControlBinop cBinop_Q2B6OT6A;
  ControlSlice cSlice_X1lWpPhr;
  ControlVar cVar_SWeR982J;
  ControlDelay cDelay_mQNgpff1;
  ControlDelay cDelay_Ib0AglKr;
  ControlBinop cBinop_x3swRFnv;
  HvTable hTable_YFLj70pI;
  ControlBinop cBinop_ojYn823S;
  ControlDelay cDelay_09yTX94u;
  ControlDelay cDelay_h0CmH2NZ;
  ControlBinop cBinop_57qVBdIf;
  HvTable hTable_h8oO5xQO;
  ControlBinop cBinop_CVCNO3hi;
  ControlVar cVar_lawuRf5L;
  ControlBinop cBinop_CyuJLTOP;
  ControlBinop cBinop_ZZdvTlpq;
  SignalVarf sVarf_vMU0dMiy;
  ControlBinop cBinop_ZOpRdyxd;
  ControlBinop cBinop_YDlDYMyf;
  ControlBinop cBinop_Jgjnj5LZ;
  SignalVarf sVarf_v5146CHO;
  ControlVar cVar_pwgQEUYW;
  ControlBinop cBinop_VJKE4Wp7;
  ControlBinop cBinop_pZrvXAJ0;
  SignalVarf sVarf_DAd6ytih;
  ControlBinop cBinop_0YPgjrGh;
  ControlBinop cBinop_cIyFQyfv;
  ControlBinop cBinop_NW1bbwDg;
  SignalVarf sVarf_5HmvK1Zs;
  ControlBinop cBinop_pZyTyxc5;
  ControlBinop cBinop_oDK9yLzS;
  SignalVarf sVarf_Fcml5uix;
  ControlVar cVar_RM3nEnhe;
  ControlBinop cBinop_xtQxSKu5;
  ControlBinop cBinop_HJQdHOFL;
  ControlBinop cBinop_b4nlLuOX;
  ControlBinop cBinop_vBtq5R3g;
  ControlBinop cBinop_i5oRyyE1;
  ControlBinop cBinop_Q8aTasbd;
  ControlBinop cBinop_vXrKq15D;
  SignalVarf sVarf_OOVwrPuo;
  ControlVar cVar_gLy1Z2bz;
  ControlBinop cBinop_7vkrnjda;
  ControlBinop cBinop_zMaAcVPe;
  SignalVarf sVarf_pU78nV89;
  SignalVarf sVarf_77qkPsKD;
  SignalVarf sVarf_DTrFANWK;
  ControlVar cVar_rJLytf7W;
  ControlBinop cBinop_Ekp02bmg;
  ControlBinop cBinop_MguaklEV;
  SignalVarf sVarf_r3m81SAw;
  SignalVarf sVarf_whYretQE;
  SignalVarf sVarf_viwzkO11;
  ControlVar cVar_pd4SaPDM;
  ControlBinop cBinop_ljEY5UF8;
  ControlBinop cBinop_EHlcJsUV;
  SignalVarf sVarf_KJ5sTtEX;
  ControlBinop cBinop_lTt8KwB0;
  ControlBinop cBinop_Da9fts4e;
  ControlBinop cBinop_myLrp0e6;
  SignalVarf sVarf_QXDg9BZ9;
  ControlVar cVar_9v5xAdIW;
  ControlBinop cBinop_O0cJWmIv;
  ControlBinop cBinop_CDukLfOc;
  SignalVarf sVarf_IagRjS0l;
  ControlBinop cBinop_7IsIVz9K;
  ControlBinop cBinop_0ExelSA9;
  ControlBinop cBinop_rznJEGE6;
  SignalVarf sVarf_NQAOVQKO;
  ControlBinop cBinop_fBjLrWbE;
  ControlBinop cBinop_LbTbR5Sg;
  SignalVarf sVarf_y4u6YPMT;
  ControlVar cVar_PpCWh6Ur;
  ControlBinop cBinop_rMWyqP1o;
  ControlBinop cBinop_jhXRhqde;
  ControlBinop cBinop_HWX2Wfll;
  ControlBinop cBinop_PUAu50wT;
  ControlBinop cBinop_ToMXzviG;
  ControlBinop cBinop_HMofqdqr;
  ControlBinop cBinop_JPk55Hif;
  SignalVarf sVarf_Ur5IEA21;
  SignalVarf sVarf_hf1JNuN7;
  SignalVarf sVarf_IxUMAFea;
  ControlVar cVar_3xGnd2Z2;
  ControlBinop cBinop_6dDgHLNz;
  ControlIf cIf_SZn20hgI;
  ControlIf cIf_LCapeWLX;
  ControlVar cVar_XoxogcfD;
  ControlVar cVar_yKIWypgw;
  ControlVar cVar_4bl0EB9d;
  ControlVar cVar_YTlXLwEv;
  ControlSlice cSlice_PspigQUr;
  ControlSlice cSlice_1s9waHBf;
  ControlVar cVar_YirgkVvW;
  ControlIf cIf_7xNfttwe;
  ControlBinop cBinop_NGQ0jzdZ;
  ControlVar cVar_Rztw5a2N;
  ControlBinop cBinop_ep0ev1y6;
  ControlBinop cBinop_obhmo8q5;
  ControlBinop cBinop_4nKNO2yl;
  ControlBinop cBinop_qjmHIHFc;
  ControlBinop cBinop_8a6HkQUn;
  ControlBinop cBinop_nBdhto1X;
  ControlBinop cBinop_NLFAna0a;
  ControlBinop cBinop_8LESIktw;
};

#endif // _HEAVY_CONTEXT_WSTD_DLAY_HPP_
